@@ -17,11 +17,9 @@
 // under the License.
 // </copyright>
 
-using System.Text.Json.Serialization;
-
 namespace OpenQA.Selenium.BiDi.Modules.Browser;
 
-public record ClientWindowInfo([property: JsonPropertyName("active")] bool IsActive, ClientWindow ClientWindow, ClientWindowState State, int Height, int Width, int X, int Y);
+public record ClientWindowInfo(bool Active, ClientWindow ClientWindow, ClientWindowState State, int Height, int Width, int X, int Y);
 
 public enum ClientWindowState
 {
