@@ -22,6 +22,6 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Modules.Browser;
 
 internal class CloseCommand()
-    : Command<CommandParameters>(CommandParameters.Empty, "browser.close");
+    : Command<CommandParameters, EmptyResult>(CommandParameters.Empty, "browser.close");
 
 public record CloseOptions : CommandOptions;
