@@ -22,7 +22,7 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Modules.Browser;
 
 internal class RemoveUserContextCommand(RemoveUserContextCommandParameters @params)
-    : Command<RemoveUserContextCommandParameters>(@params, "browser.removeUserContext");
+    : Command<RemoveUserContextCommandParameters, EmptyResult>(@params, "browser.removeUserContext");
 
 internal record RemoveUserContextCommandParameters(UserContext UserContext) : CommandParameters;
 
