@@ -22,7 +22,7 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Modules.BrowsingContext;
 
 class HandleUserPromptCommand(HandleUserPromptCommandParameters @params)
-    : Command<HandleUserPromptCommandParameters>(@params, "browsingContext.handleUserPrompt");
+    : Command<HandleUserPromptCommandParameters, EmptyResult>(@params, "browsingContext.handleUserPrompt");
 
 internal record HandleUserPromptCommandParameters(BrowsingContext Context, bool? Accept, string? UserText) : CommandParameters;
 
