@@ -21,4 +21,4 @@ using System.Collections.Generic;
 
 namespace OpenQA.Selenium.BiDi.Modules.Script;
 
-public record StackTrace(IReadOnlyCollection<StackFrame> CallFrames);
+public record StackTrace(IReadOnlyList<StackFrame> CallFrames);
