@@ -17,8 +17,7 @@
 
 import pytest
 
-from selenium.common.exceptions import InvalidSelectorException
-from selenium.common.exceptions import NoSuchElementException
+from selenium.common.exceptions import InvalidSelectorException, NoSuchElementException
 from selenium.webdriver.common.by import By
 
 # By.id positive
