@@ -29,6 +29,22 @@ module Selenium
           @bidi = Selenium::WebDriver::BiDi.new(url: socket_url)
         end
 
+        def get(url)
+          browsing_context.navigate(url)
+        end
+
+        def go_back
+          browsing_context.traverse_history(-1)
+        end
+
+        def go_forward
+          browsing_context.traverse_history(1)
+        end
+
+        def refresh
+          browsing_context.reload
+        end
+
         def quit
           super
         ensure
@@ -38,6 +54,12 @@ module Selenium
         def close
           execute(:close_window).tap { |handles| bidi.close if handles.empty? }
         end
+
+        private
+
+        def browsing_context
+          @browsing_context ||= WebDriver::BiDi::BrowsingContext.new(self)
+        end
       end # BiDiBridge
     end # Remote
   end # WebDriver
