@@ -31,12 +31,9 @@ section "Rust"
 echo "   rustfmt" >&2
 bazel run @rules_rust//:rustfmt
 
-# TODO: use bazel target when rules_python supports formatting
 section "Python"
-echo "    python - isort, black, flake8, docformatter" >&2
-pip install tox
-export TOXENV=linting
-tox -c py/tox.ini
+echo "    python - ruff" >&2
+bazel run //py:format
 
 section "Copyright"
 bazel run //scripts:update_copyright
