@@ -28,23 +28,30 @@ def calculate_hash(url):
 
 def get_chrome_milestone():
     parser = argparse.ArgumentParser()
-    parser.add_argument('--chrome_channel', default='Stable', help='Set the Chrome channel')
+    parser.add_argument(
+        "--chrome_channel", default="Stable", help="Set the Chrome channel"
+    )
     args = parser.parse_args()
     channel = args.chrome_channel
 
     r = http.request(
-        "GET", f"https://chromiumdash.appspot.com/fetch_releases?channel={channel}&num=1&platform=Mac,Linux"
+        "GET",
+        f"https://chromiumdash.appspot.com/fetch_releases?channel={channel}&num=1&platform=Mac,Linux",
     )
     all_versions = json.loads(r.data)
     # use the same milestone for all chrome releases, so pick the lowest
-    milestone = min([version["milestone"] for version in all_versions if version["milestone"]])
+    milestone = min(
+        [version["milestone"] for version in all_versions if version["milestone"]]
+    )
     r = http.request(
-        "GET", "https://googlechromelabs.github.io/chrome-for-testing/known-good-versions-with-downloads.json"
+        "GET",
+        "https://googlechromelabs.github.io/chrome-for-testing/known-good-versions-with-downloads.json",
     )
     versions = json.loads(r.data)["versions"]
 
     return sorted(
-        filter(lambda v: v["version"].split(".")[0] == str(milestone), versions), key=lambda v: parse(v["version"])
+        filter(lambda v: v["version"].split(".")[0] == str(milestone), versions),
+        key=lambda v: parse(v["version"]),
     )[-1]
 
 
@@ -266,10 +273,7 @@ js_library(
 )
 \"\"\",
     )
-""" % (
-            linux,
-            linux_hash.lower()
-        )
+""" % (linux, linux_hash.lower())
 
     return content
 
@@ -277,13 +281,18 @@ js_library(
 def edgedriver():
     r_stable = http.request("GET", "https://msedgedriver.azureedge.net/LATEST_STABLE")
     stable_version = r_stable.data.decode("utf-16").strip()
-    major_version = stable_version.split('.')[0]
-    r = http.request("GET", f"https://msedgedriver.azureedge.net/LATEST_RELEASE_{major_version}_LINUX")
+    major_version = stable_version.split(".")[0]
+    r = http.request(
+        "GET",
+        f"https://msedgedriver.azureedge.net/LATEST_RELEASE_{major_version}_LINUX",
+    )
     linux_version = r.data.decode("utf-16").strip()
 
     content = ""
 
-    linux = "https://msedgedriver.azureedge.net/%s/edgedriver_linux64.zip" % linux_version
+    linux = (
+        "https://msedgedriver.azureedge.net/%s/edgedriver_linux64.zip" % linux_version
+    )
     sha = calculate_hash(linux)
     content = (
         content
@@ -308,7 +317,10 @@ js_library(
         % (linux, sha)
     )
 
-    r = http.request("GET", f"https://msedgedriver.azureedge.net/LATEST_RELEASE_{major_version}_MACOS")
+    r = http.request(
+        "GET",
+        f"https://msedgedriver.azureedge.net/LATEST_RELEASE_{major_version}_MACOS",
+    )
     macos_version = r.data.decode("utf-16").strip()
     mac = "https://msedgedriver.azureedge.net/%s/edgedriver_mac64.zip" % macos_version
     sha = calculate_hash(mac)
@@ -340,7 +352,9 @@ js_library(
 def geckodriver():
     content = ""
 
-    r = http.request("GET", "https://api.github.com/repos/mozilla/geckodriver/releases/latest")
+    r = http.request(
+        "GET", "https://api.github.com/repos/mozilla/geckodriver/releases/latest"
+    )
     for a in json.loads(r.data)["assets"]:
         if a["name"].endswith("-linux64.tar.gz"):
             url = a["browser_download_url"]
@@ -411,21 +425,30 @@ def firefox():
 
 
 def firefox_version_data():
-    versions = http.request("GET", "https://product-details.mozilla.org/1.0/firefox_versions.json")
+    versions = http.request(
+        "GET", "https://product-details.mozilla.org/1.0/firefox_versions.json"
+    )
     return versions.data
 
 
 def firefox_linux(version):
     if int(version.split(".")[0]) < 135:
-        return "https://ftp.mozilla.org/pub/firefox/releases/%s/linux-x86_64/en-US/firefox-%s.tar.bz2" % (
-        version, version)
+        return (
+            "https://ftp.mozilla.org/pub/firefox/releases/%s/linux-x86_64/en-US/firefox-%s.tar.bz2"
+            % (version, version)
+        )
     else:
-        return "https://ftp.mozilla.org/pub/firefox/releases/%s/linux-x86_64/en-US/firefox-%s.tar.xz" % (
-        version, version)
+        return (
+            "https://ftp.mozilla.org/pub/firefox/releases/%s/linux-x86_64/en-US/firefox-%s.tar.xz"
+            % (version, version)
+        )
 
 
 def firefox_mac(version):
-    return "https://ftp.mozilla.org/pub/firefox/releases/%s/mac/en-US/Firefox%%20%s.dmg" % (version, version)
+    return (
+        "https://ftp.mozilla.org/pub/firefox/releases/%s/mac/en-US/Firefox%%20%s.dmg"
+        % (version, version)
+    )
 
 
 def print_firefox(version, workspace_name, sha_linux, sha_mac):
